==> oto-service-api-0.1.12-xt-20231023.034207-2-sources.jar: cn/com/duiba/oto/oto/service/api/remoteservice/serviceCard/RemoteServiceCardService.java <==
package cn.com.duiba.oto.oto.service.api.remoteservice.serviceCard;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.oto.dto.oto.serviceCard.ServiceCardDto;
import cn.com.duiba.oto.dto.oto.serviceCard.ServiceCardOrderConfigDto;
import cn.com.duiba.oto.param.oto.pay.response.wxpay.WxPayLiteChargeResponse;
import cn.com.duiba.oto.param.oto.serviceCard.ActivateParam;
import cn.com.duiba.oto.param.oto.serviceCard.OrderParam;
import cn.com.duiba.oto.param.oto.serviceCard.SearchServiceCardParam;
import cn.com.duiba.oto.param.oto.serviceCard.SendMsgParam;
import cn.com.duiba.oto.util.PageResult;

import java.util.List;

/**
 * 客户养老服务卡
 * @author xiaotian
 * @date 2023/9/06 14:07
 */
@AdvancedFeignClient
public interface RemoteServiceCardService {

    /**
     * 服务卡列表
     */
    PageResult<ServiceCardDto> list(SearchServiceCardParam pageQuery);

    /**
     * 新增/修改服务卡
     */
    Long saveOrUpdate(ServiceCardDto serviceCardDto) throws BizException;

    /**
     * 删除服务卡
     */
    @Deprecated
    Boolean del(Long custId) throws BizException;

    /**
     * 删除服务卡(根据卡类型)
     */
    Boolean del(Long custId,Integer cardType) throws BizException;

    /**
     * 根据客户id，获取卡片信息
     * @param custId
     * @return
     */
    @Deprecated
    ServiceCardDto getCard(Long custId);

    /**
     * 根据客户id，获取卡片信息
     * @param custId
     * @return
     */
    List<ServiceCardDto> getCardList(Long custId);

    /**
     * 发送验证码
     */
    Boolean sendMsg(SendMsgParam param) throws BizException;

    /**
     * 激活服务卡
     */
    Boolean activate(ActivateParam param) throws BizException;

    /**
     * 获取在线订单的配置信息
     *
     * @return
     */
    @Deprecated
    ServiceCardOrderConfigDto getWxCardConfig();

    /**
     * 获取在线订单的配置信息(V2),包含不同类型的卡片
     * @return
     */
    List<ServiceCardOrderConfigDto> getWxCardConfigV2();

    /**
     * 下单服务卡
     */
    WxPayLiteChargeResponse order(OrderParam param) throws BizException;
}

==> oto-service-api-0.1.66-xt-20240722.063241-3-sources.jar: cn/com/duiba/oto/oto/service/api/remoteservice/serviceCard/RemoteServiceCardService.java <==
package cn.com.duiba.oto.oto.service.api.remoteservice.serviceCard;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.oto.dto.oto.serviceCard.ServiceCardDto;
import cn.com.duiba.oto.dto.oto.serviceCard.ServiceCardOrderConfigV2Dto;
import cn.com.duiba.oto.param.oto.pay.response.wxpay.WxPayLiteChargeResponse;
import cn.com.duiba.oto.param.oto.serviceCard.ActivateParam;
import cn.com.duiba.oto.param.oto.serviceCard.OrderForAlipayParam;
import cn.com.duiba.oto.param.oto.serviceCard.OrderParam;
import cn.com.duiba.oto.param.oto.serviceCard.SearchServiceCardParam;
import cn.com.duiba.oto.param.oto.serviceCard.SearchServiceCardV2Param;
import cn.com.duiba.oto.param.oto.serviceCard.SendMsgParam;
import cn.com.duiba.oto.util.PageResult;

import java.util.List;

/**
 * 客户养老服务卡
 * @author xiaotian
 * @date 2023/9/06 14:07
 */
@AdvancedFeignClient
public interface RemoteServiceCardService {

    /**
     * 服务卡列表
     */
    PageResult<ServiceCardDto> list(SearchServiceCardParam pageQuery);

    /**
     * 客户列表
     */
    PageResult<Long> listForPage2(SearchServiceCardV2Param pageQuery);

    /**
     * 新增/修改服务卡
     */
    Long saveOrUpdate(ServiceCardDto serviceCardDto) throws BizException;

    /**
     * 删除服务卡(根据卡类型)
     */
    Boolean delByCardType(Long custId, Integer cardType) throws BizException;

    /**
     * 根据客户id，获取卡片信息
     *
     * @param custId
     * @return
     */
    List<ServiceCardDto> getCardList(Long custId);

    /**
     * 根据客户id，获取卡片信息
     *
     * @param custId
     * @return
     */
    @Deprecated
    ServiceCardDto getCard(Long custId);


    /**
     * 根据客户id，获取卡片信息
     *
     * @param custIds
     * @return
     */
    List<ServiceCardDto> getCardListByIds(List<Long> custIds);


    /**
     * 发送验证码
     */
    Boolean sendMsg(SendMsgParam param) throws BizException;

    /**
     * 激活服务卡
     */
    Boolean activate(ActivateParam param) throws BizException;

    /**
     * 获取在线订单的配置信息(V2),包含不同类型的卡片
     *
     * @return
     */
    List<ServiceCardOrderConfigV2Dto> getWxCardConfigV2();

    /**
     * 下单服务卡
     */
    WxPayLiteChargeResponse order(OrderParam param) throws BizException;

    /**
     * 支付宝付款码生成（二维码链接）
     */
    String orderForAlipay(OrderForAlipayParam param);
}
